@@ -10,6 +10,7 @@ test_that("Metadata", {
   skip_on_cran()
   skip_if_offline()
   skip_if_not(aemet_detect_api_key(), message = "No API KEY")
+  Sys.sleep(30)
 
   meta <- aemet_forecast_fires(extract_metadata = TRUE)
   expect_s3_class(meta, "tbl")
@@ -20,7 +21,9 @@ test_that("rasters", {
   skip_on_cran()
   skip_if_offline()
   skip_if_not(aemet_detect_api_key(), message = "No API KEY")
+  skip_if_not_installed("terra")
 
+  library(terra)
   rr <- aemet_forecast_fires()
   expect_s4_class(rr, "SpatRaster")
 
