@@ -16,4 +16,10 @@ test_that("dms2decdegrees_2 works", {
 test_that("first and last works", {
   expect_snapshot(first_day_of_year(2000))
   expect_snapshot(last_day_of_year(2020))
+
+  expect_snapshot(first_day_of_year(), error = TRUE)
+  expect_snapshot(last_day_of_year(), error = TRUE)
+
+  expect_snapshot(first_day_of_year("A"), error = TRUE)
+  expect_snapshot(last_day_of_year("B"), error = TRUE)
 })
